import React, { useState, useEffect } from "react";
import { View, Animated, Image } from "react-native";

export default function LazyImage({
  source,
  thumbnail,
  style,
  resizeMode = "cover",
  blurRadius = 3,
  backgroundColor = "#e1e4e8"
}) {
  const [imgStyle, setImgStyle] = useState({});
  const thumbnailAnimated = new Animated.Value(1);
  const imageAnimated = new Animated.Value(0);

  useEffect(
    () => {
      calculateImgDimens();
    },
    [source, thumbnail, style]
  );

  const calculateImgDimens = () => {
    if (style && style.height && style.width) {
      setImgStyle({ ...style });
    } else if (style && (style.height || style.width)) {
      var styleData = {};
      Image.getSize(
        source && source.uri ? source.uri : source,
        (width, height) => {
          if (style.height) {
            styleData = {
              width: style.height / height * width,
              height: style.height
            };
          } else if (style.width) {
            styleData = {
              height: style.width / width * height,
              width: style.width
            };
          }
          setImgStyle({ ...styleData });
        },
        error => {
          console.warn(`Couldn't get the image size: ${error.message}`);
        }
      );
    }
  };

  const finishLoading = () => {
    setTimeout(() => {
      Animated.parallel([
        Animated.timing(thumbnailAnimated, {
          toValue: 0,
          duration: 500,
          useNativeDriver: true
        }),
        Animated.timing(imageAnimated, {
          toValue: 1,
          duration: 500,
          useNativeDriver: true
        })
      ]).start(() =>
        console.log(`finish animate ${thumbnailAnimated} ${imageAnimated}`)
      );
    }, 250);
  };

  return (
    <View style={[styles.container, imgStyle, { backgroundColor }]}>
      <Animated.Image
        source={source}
        style={[imgStyle, { opacity: imageAnimated }]}
        resizeMode={resizeMode}
        onLoad={finishLoading}
      />
      <Animated.Image
        source={thumbnail ? thumbnail : source}
        style={[imgStyle, styles.blurImage, { opacity: thumbnailAnimated }]}
        resizeMode={resizeMode}
        blurRadius={Platform.OS === "ios" ? blurRadius + 5 : blurRadius}
      />
    </View>
  );
}

const styles = {
  container: {
    justifyContent: "center",
    alignItems: "center"
  },
  blurImage: {
    position: "absolute",
    top: 0,
    bottom: 0,
    left: 0,
    right: 0
  }
};
